aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'Bugzilla')
-rw-r--r--Bugzilla/BugUrl/GitLab.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/Bugzilla/BugUrl/GitLab.pm b/Bugzilla/BugUrl/GitLab.pm
index 8e546c1dc..d2e75dcce 100644
--- a/Bugzilla/BugUrl/GitLab.pm
+++ b/Bugzilla/BugUrl/GitLab.pm
@@ -20,9 +20,9 @@ use base qw(Bugzilla::BugUrl);
sub should_handle {
my ($class, $uri) = @_;
-# GitLab issue URLs can have the form:
-# https://gitlab.com/projectA/subprojectB/subprojectC/../issues/53
- return ($uri->path =~ m!^/.*/issues/\d+$!) ? 1 : 0;
+ # GitLab issue and merge request URLs can have the form:
+ # https://gitlab.com/projectA/subprojectB/subprojectC/../(issues|merge_requests)/53
+ return ($uri->path =~ m!^/.*/(issues|merge_requests)/\d+$!) ? 1 : 0;
}
sub _check_value {